<?php
defined('BASEPATH') OR exit('No direct script access allowed');

class Home_model extends CI_Model {

	
	public function homepage_info()
	{
		$d = $this->db->get('homepage');
		return $d->row();
	}

	public function fetch_search_data($query)
    {   
        $this->db->select('*');
        $this->db->from('property_info');
        $this->db->join('developers','developers.developer_id = property_info.developer_id');
        $this->db->join('neighbourhood','neighbourhood.community_id = property_info.community_id');
        $this->db->join('property_types','property_types.type_id = property_info.property_type_id');
        
        $this->db->where('property_status', 'NEW');
        $this->db->where('published_status', 'Published');
        
        $this->db->group_start();
        $this->db->or_like('property_name', $query);
        $this->db->or_like('developer_name', $query);
        $this->db->or_like('community_name', $query);
        $this->db->or_like('type_name', $query);
        $this->db->group_end();
        

        // $this->db->group_by('property_name,developer_name,community_name');
        $this->db->distinct();
        $d = $this->db->get();
        if($d->num_rows() > 0)
        {
            return $d->result_array();
        }else{

            return false;
        }
    }

	public function dubai_properties()
	{
		$prop = array(195912, 195589, 195587, 55738, 196129, 195606, 196173, 196117, 196135, 80139, 196167, 80155);
		$this->db->select('property_info.property_id, neighbourhood.cover_image, min(CASE WHEN property_info.starting_price > 0 THEN starting_price ELSE NULL END) as price, neighbourhood.community_name, neighbourhood.slug');
		$this->db->from('property_info');
		$this->db->join('neighbourhood', 'neighbourhood.community_id = property_info.community_id');
		$this->db->where('property_info.published_status', 'Published');
		$this->db->where('property_info.property_status', 'NEW');
		

		$this->db->where_in('property_info.community_id', $prop);
		// $this->db->limit(12);
		$this->db->group_by('property_info.community_id');
		$this->db->order_by("FIELD(property_info.community_id, '" . implode("', '", $prop) . "')");
		$d = $this->db->get();

		return $d->result();
		// echo '<pre>';
		// print_r($d->result());
		// exit();
	}

	public function developers_info()
	{
		// $this->db->limit(12);
		$prop = array(1, 2, 21, 28, 55, 10, 3, 14, 35, 30, 33, 41,);
		$this->db->where_in('developer_id', $prop);
		$this->db->order_by("FIELD(developer_id, '" . implode("', '", $prop) . "')");
		// $this->db->order_by('projects_count', 'desc');
		$d = $this->db->get('developers');
		return $d->result();
	}

	public function blog_info_first()
	{
		$this->db->where('website', 'UAE-Offplan');
		$this->db->where('category', 'real-estate');
		$this->db->where('status', 'Published');
		$this->db->order_by('blog_id', 'desc');
		$this->db->limit(2,0);
		$d = $this->db->get('uae_offplan_blog');
		return $d->result();
	}

	public function blog_info_second()
	{
		$this->db->where('website', 'UAE-Offplan');
		$this->db->where('category', 'real-estate');
		$this->db->where('status', 'Published');
		$this->db->order_by('blog_id', 'desc');
		$this->db->limit(3,2);
		$d = $this->db->get('uae_offplan_blog');
		return $d->result();
	}

	public function homepage_faq()
	{
		$this->db->limit(4);
		$this->db->order_by('faq_id', 'desc');
		$d = $this->db->get('homepage_faq');
		return $d->result();
	}

	public function loadPropertyTypes()
	{	
		$this->db->group_by('type_name');
		$d = $this->db->get('property_types');

		$types[''] = '';
		foreach ($d->result() as $value) {
			$types[$value->type_id] = $value->type_name;
		}
		return $types;
	}

	public function loadDevelopers()
	{
		$d = $this->db->get('developers');

		$developers[''] = '';
		foreach ($d->result() as $value) {
			$developers[$value->developer_id] = $value->developer_name;
		}
		return $developers;
	}

	public function loadCommunity()
	{
		$d = $this->db->get('neighbourhood');

		$community[''] = '';
		foreach ($d->result() as $value) {
			$community[$value->community_id] = $value->community_name;
		}
		return $community;
	}

	public function featured_property()
	{
		$this->db->select('p.property_id, p.property_name, p.starting_price, p.cover_image, n.community_name, t.type_name, p.slug, d.developer_name');
		$this->db->from('property_info p');
		$this->db->join('neighbourhood n', 'n.community_id = p.community_id');
		$this->db->join('property_types t', 't.type_id = p.property_type_id');
		$this->db->join('developers d', 'd.developer_id = p.developer_id');
		$this->db->where('p.property_featured', 'featured');
		$this->db->limit(12);
		$d = $this->db->get();
		return $d->result();
	}

	public function latest_property()
	{
		$this->db->select('p.property_id, p.property_name, p.starting_price, p.cover_image, n.community_name, t.type_name, p.slug, d.developer_name');
		$this->db->from('property_info p');
		$this->db->join('neighbourhood n', 'n.community_id = p.community_id');
		$this->db->join('property_types t', 't.type_id = p.property_type_id');
		$this->db->join('developers d', 'd.developer_id = p.developer_id');
		$this->db->where('p.property_status', 'NEW');
		$this->db->where('p.published_status', 'Published');
		$this->db->limit(12);
		$this->db->order_by('p.property_id', 'desc');
		$d = $this->db->get();
		return $d->result();
	}

	public function new_projects()
    {
        $this->db->select('i.cover_image,i.property_name,i.starting_price,d.developer_name,n.community_name,i.slug');
        $this->db->from('property_info i');
        $this->db->join('developers d','i.developer_id = d.developer_id');
        $this->db->join('neighbourhood n','n.community_id = i.community_id');
        $this->db->where('menu_property_status','featured');
        $this->db->limit(5);
        $this->db->order_by('property_id','desc');
        $d = $this->db->get();
        return $d->result();
    }

    public function new_all_properties_prices()
    {
        $this->db->select('MIN(starting_price) AS min_price');
        $this->db->from('property_info');
        $this->db->where('property_status','NEW');
        $this->db->where('starting_price>',0);
        $d = $this->db->get();
        return $d->row();
    }

    public function new_apartments_prices()
    {
        $this->db->select('MIN(starting_price) AS min_price');
        $this->db->from('property_info');
        $this->db->where('property_type_id',1);
        $this->db->where('starting_price>',0);
        $d = $this->db->get();
        return $d->row();
    }

    public function new_townhouses_prices()
    {
        $this->db->select('MIN(starting_price) AS min_price');
        $this->db->from('property_info');
        $this->db->where('property_type_id',4);
        $this->db->where('starting_price>',0);
        $d = $this->db->get();
        return $d->row();
    }

    public function new_penthouses_prices()
    {
        $this->db->select('MIN(starting_price) AS min_price');
        $this->db->from('property_info');
        $this->db->where('property_type_id',2);
        $this->db->where('starting_price>',0);
        $d = $this->db->get();
        return $d->row();
    }

    public function new_villas_prices()
    {
        $this->db->select('MIN(starting_price) AS min_price');
        $this->db->from('property_info');
        $this->db->where('property_type_id',3);
        $this->db->where('starting_price>',0);
        $d = $this->db->get();
        return $d->row();
    }

    public function developers_menu()
    {
        $this->db->select('developer_name, developer_logo, slug');
        $this->db->from('developers');
        $this->db->where('menu_developer_status','featured');
        // $this->db->where('developer_id',1);
        // $this->db->where('developer_id',1);
        // $this->db->or_where('developer_id',2);
        // $this->db->or_where('developer_id',3);
        // $this->db->or_where('developer_id',4);

        $d = $this->db->get();
        return $d->result();
    }

    public function waterfront_price()
    {

        $this->db->select('starting_price');
        $this->db->from('property_info');
        $this->db->where('waterfront_property','waterfront-properties');
        $d = $this->db->get();
        return $d->result();
    }
    public function beachfront_price()
    {

        $this->db->select('starting_price');
        $this->db->from('property_info');
        $this->db->where('beachfront_property','beachfront-properties');
        $d = $this->db->get();
        return $d->result();
    }

    public function ultraluxury_price()
    {

        $this->db->select('starting_price');
        $this->db->from('property_info');
        $this->db->where('ultra_luxury_property','ultra-luxury-properties');
        $d = $this->db->get();
        return $d->result();
    }
    public function golfcourse_price()
    {

        $this->db->select('starting_price');
        $this->db->from('property_info');
        $this->db->where('golf_course_property','golf-course-properties');
        $d = $this->db->get();
        return $d->result();
    }

    public function branded_price()
    {

        $this->db->select('starting_price');
        $this->db->from('property_info');
        $this->db->where('branded_property','branded');
        $d = $this->db->get();
        return $d->result();
    }

    public function areas_menu()
    {
        $this->db->select('community_name, cover_image, slug');
        $this->db->from('neighbourhood');
        $this->db->where('menu_area_status','featured');
        // $this->db->where('community_id',195589);
        // $this->db->or_where('community_id',55738);
        // $this->db->or_where('community_id',196129);
        // $this->db->or_where('community_id',195909);
        $d = $this->db->get();
        return $d->result();
    }

    public function getProjectDetail($slug)
    {
    	$this->db->select('p.property_id, p.property_name, p.slug, p.project_logo, p.project_name, p.headline, p.cover_image, p.starting_price, p.on_booking, p.on_construction, p.on_handover, p.completion_date, d.developer_logo, n.community_name, p.max_size, t.type_name,p.attributes_short_content, p.latitude, p.longitude, p.full_content, p.project_logo_mobile, d.developer_logo_mobile, d.developer_name1,d.developer_name,p.meta_title, p.meta_desc, p.meta_keywords, p.mobile_cover_image,p.color_selector, p.project_logo_text');
    	$this->db->from('property_info p');
    	$this->db->join('developers d', 'd.developer_id = p.developer_id');
    	$this->db->join('neighbourhood n', 'n.community_id = p.community_id');
    	$this->db->join('property_types t', 't.type_id = p.property_type_id');
    	$this->db->where('p.slug', $slug);
    	$d = $this->db->get();

    	return $d->row();
    }

    public function loadCitiesDetail()
    {
    	$cities = array(1,2,3,4);
    	$this->db->select('p.city_id, count(*) AS count_property, min(p.starting_price) as price, c.city_name, c.slug');
    	$this->db->join('cities c','c.city_id = p.city_id');
    	$this->db->from('property_info p');
    	$this->db->where_in('p.city_id',$cities);
    	$this->db->where('p.starting_price<>',0);
    	$this->db->group_by('p.city_id');
    	$d = $this->db->get();

    	return $d->result();
    }
    public function loadCitiesDetailOther()
    {
    	$cities = array(1,2,3,4);
    	$this->db->select('p.city_id, count(*) AS count_property, min(p.starting_price) as price, c.city_name, c.slug');
    	$this->db->join('cities c','c.city_id = p.city_id');
    	$this->db->from('property_info p');
    	$this->db->where_not_in('p.city_id',$cities);
    	$this->db->where('p.starting_price<>',0);
    	$this->db->group_by('p.city_id');
    	$d = $this->db->get();

    	return $d->result();
    }

    public function loadCommunitiesDetail()
    {
    	$communities = array(195587,195589,55738,195909);
    	$this->db->select('p.community_id, count(*) AS count_property, min(p.starting_price) as price, c.community_name, c.slug');
    	$this->db->join('neighbourhood c','c.community_id = p.community_id');
    	$this->db->from('property_info p');
    	$this->db->where_in('p.community_id',$communities);
    	$this->db->where('p.starting_price<>',0);
    	$this->db->group_by('p.community_id');
    	$d = $this->db->get();

    	return $d->result();
    }

    public function loadCommunitiesDetailOther($offset, $limit)
    {
    	$communities = array(195587,195589,55738,195909);
    	$this->db->select('p.community_id, count(*) AS count_property, min(p.starting_price) as price, c.community_name, c.slug');
    	$this->db->join('neighbourhood c','c.community_id = p.community_id');
    	$this->db->from('property_info p');
    	$this->db->where_not_in('p.community_id',$communities);
    	$this->db->where('p.starting_price<>',0);
    	$this->db->limit($limit, $offset);	
    	$this->db->group_by('p.community_id');
    	$d = $this->db->get();

    	return $d->result();
    }

    public function getBedroomDetail($property_id)
    {
    	$this->db->select('MIN(bedroom)AS min_bedroom, MAX(bedroom) AS max_bedroom');
    	$this->db->where('property_id', $property_id);
    	$d = $this->db->get('property_bedroom_detail');
    	
    	return $d->result();
    }

    public function content_detail($property_id)
    {
    	$this->db->where('property_id', $property_id);
    	$d = $this->db->get('property_content_detail');
    	
    	return $d->result();
    }

    public function nearby_detail($property_id)
    {
    	$this->db->where('property_id', $property_id);
    	$d = $this->db->get('property_nearby_detail');
    	
    	return $d->result();
    }

    public function getBuyProperty($project_name)
    {
    	$this->db->select('p.property_id, p.property_name, p.project_name, p.slug, p.for_sale_bedroom, p.max_size, p.project_logo, p.headline, p.cover_image, p.starting_price, p.on_booking, p.on_construction, p.on_handover, p.completion_date, n.community_name, t.type_name');
    	$this->db->from('property_info p');
    	// $this->db->join('developers d', 'd.developer_id = p.developer_id');
    	$this->db->join('neighbourhood n', 'n.community_id = p.community_id');
    	$this->db->join('property_types t', 't.type_id = p.property_type_id');
    	$this->db->where('p.project_name', $project_name);
    	$this->db->where('p.property_status', 'SALE');
    	$this->db->where('p.published_status', 'Published');
    	$d = $this->db->get();

    	return $d->result();
    }

    public function getPropertyUsps($property_id)
    {
    	$this->db->select('p.property_id, u.project_usps, p.project_name');
    	$this->db->from('property_info p');
    	$this->db->join('project_usps_detail u', 'u.property_id = p.property_id');
    	$this->db->where('u.property_id', $property_id);
    	// $this->db->group_by('p.property_id');
    	$d = $this->db->get();

    	// echo '<pre>';
    	return $d->result();
    	// exit();
    }

    public function loadGallery($property_id)
    {
    	$this->db->where('property_id', $property_id);
    	$d = $this->db->get('property_images_upload');
    	return $d->result();

    }

    public function loadExteriorGallery($property_id)
    {
    	$this->db->where('property_id', $property_id);
    	$d = $this->db->get('property_exterior_images_upload');
    	return $d->result();
    }

    public function loadInteriorGallery($property_id)
    {
    	$this->db->where('property_id', $property_id);
    	$d = $this->db->get('property_interior_images_upload');
    	return $d->result();
    }

    public function loadAmenities($property_id)
    {
    	$this->db->select('a.amenity_icon, a.amenity_name');
    	$this->db->from('property_amenities_detail d');
    	// $this->db->join('property_amenities_detail d', 'd.property_id = p.property_id');
    	$this->db->join('amenities a', 'd.amenity_id = a.amenity_id');
    	$this->db->where('d.property_id', $property_id);
    	$d = $this->db->get();
    	return $d->result();
    }

    public function similar_property()
	{
		$this->db->select('p.property_id, p.property_name, p.starting_price, p.cover_image, n.community_name, t.type_name, p.slug, d.developer_name');
		$this->db->from('property_info p');
		$this->db->join('neighbourhood n', 'n.community_id = p.community_id');
		$this->db->join('property_types t', 't.type_id = p.property_type_id');
		$this->db->join('developers d', 'd.developer_id = p.developer_id');
		$this->db->where('p.property_status', 'NEW');
		$this->db->where('p.published_status', 'Published');
		$this->db->limit(12);
		$this->db->order_by('p.property_id', 'desc');
		$d = $this->db->get();
		return $d->result();
	}

	public function getForSaleProperty()
	{
		$this->db->select('p.property_id, p.property_name, p.starting_price, p.cover_image, n.community_name, t.type_name, p.slug, p.for_sale_bedroom, p.max_size');
		$this->db->from('property_info p');
		$this->db->join('neighbourhood n', 'n.community_id = p.community_id');
		$this->db->join('property_types t', 't.type_id = p.property_type_id');
		$this->db->where('p.property_status', 'SALE');
		$this->db->where('p.published_status', 'Published');
		$this->db->limit(12);
		$this->db->order_by('p.property_id', 'desc');
		$d = $this->db->get();
		return $d->result();
	}

	public function cities_properties()
	{
		$this->db->select('property_id, cities.background_image, min(starting_price) as price, cities.city_name, cities.slug');
		$this->db->from('property_info');
		$this->db->join('cities', 'cities.city_id = property_info.city_id');
		$this->db->where('published_status', 'Published');
		$this->db->where('property_status', 'NEW');
		$this->db->where('starting_price<>', 0);
		// $this->db->where_in('community_id', $prop);
		$this->db->limit(12);
		$this->db->group_by('property_info.city_id');
		$d = $this->db->get();
		return $d->result();
	}

	// public function getTypesWithCities($slug)
	// {
	// 	$this->db->select('t.type_name, c.slug, c.heading1, t.type_id');
	// 	$this->db->from('types_with_cities c');
	// 	$this->db->join('property_types t', 't.type_id = c.type_id');
	// 	$this->db->where('c.slug', $slug);
	// 	$d = $this->db->get();
	// 	return $d->row();
	// }

	public function getSaleProperty($type)
    {
    	$this->db->where('type_name', $type);
    	$this->db->where('status', 'sale');
    	$t = $this->db->get('property_types');

    	$this->db->select('p.property_id, p.property_name, p.project_name, p.slug, p.for_sale_bedroom, p.max_size, p.project_logo, p.headline, p.cover_image, p.starting_price, p.on_booking, p.on_construction, p.on_handover, p.completion_date, n.community_name, t.type_name');
    	$this->db->from('property_info p');
    	$this->db->join('neighbourhood n', 'n.community_id = p.community_id');
    	$this->db->join('property_types t', 't.type_id = p.property_type_id');
    	$this->db->where('p.property_type_id', $t->row()->type_id);
    	// $this->db->where('p.property_type_with_cities_featured', 'featured');
    	$this->db->where('p.property_status', 'SALE');
    	$this->db->where('p.published_status', 'Published');
    	$this->db->order_by("CASE WHEN property_type_with_cities_featured = 'featured' THEN 1 ELSE 2 END");
        $this->db->order_by('p.property_type_with_cities_position','asc');
        $this->db->limit(12);
        // $this->db->group_by('p.property_id');
    	$d = $this->db->get();

    	return $d->result();
    }

    public function getCityID($city_name)
    {
    	$this->db->where('slug', $city_name);
    	$d = $this->db->get('cities');
    	return $d->row()->city_id;
    }

    public function getTypeID($type_name)
    {
    	$this->db->where('slug', $type_name);
    	$this->db->where('status', 'new');
    	$d = $this->db->get('property_types');
    	return $d->row()->type_id;
    }

    public function load_offplan_properties($city_id, $type_id, $offset, $limit, $sort, $count=false) {
       

        $d = $this->db
                    ->select('PI.property_id,PI.property_name, N.community_id, N.community_name, PI.starting_price, PI.cover_image,PI.slug,PI.sold_out_status,PI.completion_date,PI.completion_quarter,PI.mark_coming_soon_ready_to_move,PT.type_name,D.developer_name,PI.max_size, PI.property_community_featured, PI.project_name,PI.slug')
                    ->from('property_info PI')
                    ->join('property_types PT', 'PI.property_type_id=PT.type_id')
                    ->join('neighbourhood N', 'N.community_id=PI.community_id')
                    ->join('developers D', 'D.developer_id=PI.developer_id')
                    ->join('cities C', 'C.city_id=PI.city_id')
                    // ->where('PT.type_name', $slug)
                    ->where('PI.city_id', $city_id)
                    ->where('PI.property_type_id', $type_id)
                    // ->where('PI.property_status', 'NEW')
                    // ->where('PI.published_status', 'Published')
                    // ->where('PI.property_type_with_cities_position<>', 0)
                    ->order_by("CASE WHEN property_type_with_cities_featured = 'featured' THEN 1 ELSE 2 END")
                    ->order_by('PI.property_type_with_cities_position','asc');
                    // ->order_by('PI.property_id',$sort)
                
                if ($count)
                {
                	return $this->db->count_all_results();
                }else{
                	$this->db->limit($limit, $offset);
	                $d = $this->db->get();

		                if ($d->num_rows() > 0 )
		                {
		                    return $d->result();
		                    
		                }
		            }
          
    }

    public function fetchMapAllProperties()
    {
    	$this->db->select('p.latitude, p.longitude, p.cover_image, p.property_name, p.slug');
    	$this->db->from('property_info p');
    	$this->db->where('p.property_status', 'NEW');
    	$this->db->where('p.published_status', 'Published');
    	$this->db->where('p.latitude<>', '');
    	$this->db->where('p.longitude<>', '');
    	$d = $this->db->get();
    	return $d->result_array();

    }

    public function fetchMapAllPropertiesTypes($city, $type)
    {
    	$this->db->select('p.latitude, p.longitude, p.cover_image, p.property_name, p.slug');
    	$this->db->from('property_info p');
    	$this->db->join('cities c', 'c.city_id = p.city_id');
    	$this->db->join('property_types t', 't.type_id = p.property_type_id');
    	$this->db->where('c.city_name', $city);
    	$this->db->where('t.type_name', $type);
    	$this->db->where('p.property_status', 'NEW');
    	$this->db->where('p.published_status', 'Published');
    	$this->db->where('p.latitude<>', '');
    	$this->db->where('p.longitude<>', '');
    	$d = $this->db->get();
    	return $d->result_array();

    }

    public function getProjectsPage()
    {
    	$d = $this->db->get('new_properties_page');
    	return $d->row();
    }

    public function getProjectsContentDetail()
    {
    	$d = $this->db->get('new_property_content_detail_page');
    	return $d->result();
    }

    public function types_with_cities_info($slug)
    {
    	$this->db->select("*");
    	$this->db->from('types_with_cities');
    	$this->db->join('cities', 'cities.city_id = types_with_cities.city_id');
    	$this->db->where('types_with_cities.slug', $slug);
    	$this->db->where('types_with_cities.status', 'new');
    	$d = $this->db->get();
    	return $d->row();
    }

    public function types_with_cities_sale_info($slug)
    {
    	$this->db->select("*");
    	$this->db->from('types_with_cities');
    	$this->db->join('cities', 'cities.city_id = types_with_cities.city_id');
    	$this->db->where('types_with_cities.slug', $slug);
    	$this->db->where('types_with_cities.status', 'for-sale');
    	$d = $this->db->get();
    	return $d->row();
    }
}